@@ -1,31 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Kurt Pattyn <pattyn.kurt@gmail.com>.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 Kurt Pattyn <pattyn.kurt@gmail.com>.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the QtWebSockets module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -41,17 +47,17 @@
     WebSockets is a web technology providing full-duplex communications channels over
     a single TCP connection.
     The WebSocket protocol was standardized by the IETF as
-    \l {http://tools.ietf.org/html/rfc6455} {RFC 6455} in 2011.
+    \l {RFC 6455} in 2011.
     QWebSocket can both be used in a client application and server application.
 
     This class was modeled after QAbstractSocket.
 
     QWebSocket currently does not support
-    \l {http://tools.ietf.org/html/rfc6455#page-39} {extensions} and
-    \l {http://tools.ietf.org/html/rfc6455#page-12} {subprotocols}.
+    \l {WebSocket Extensions} and
+    \l {WebSocket Subprotocols}.
 
     QWebSocket only supports version 13 of the WebSocket protocol, as outlined in
-    \l {http://tools.ietf.org/html/rfc6455}{RFC 6455}.
+    \l {RFC 6455}.
 
     \note Some proxies do not understand certain HTTP headers used during a WebSocket handshake.
     In that case, non-secure WebSocket connections fail. The best way to mitigate against
@@ -60,7 +66,7 @@
     \warning To generate masks, this implementation of WebSockets uses the cryptographically
     insecure qrand() function.
     For more information about the importance of good masking,
-    see \l {http://w2spconf.com/2011/papers/websocket.pdf}.
+    see \l {"Talking to Yourself for Fun and Profit" by Lin-Shung Huang et al}.
     The best measure against attacks mentioned in the document above,
     is to use QWebSocket over a secure connection (\e wss://).
     In general, always be careful to not have 3rd party script access to
@@ -259,12 +265,12 @@ QT_BEGIN_NAMESPACE
  * \brief Creates a new QWebSocket with the given \a origin,
  * the \a version of the protocol to use and \a parent.
  *
- * The \a origin of the client is as specified in \l {http://tools.ietf.org/html/rfc6454}{RFC 6454}.
+ * The \a origin of the client is as specified in \l {RFC 6454}.
  * (The \a origin is not required for non-web browser clients
- * (see \l {http://tools.ietf.org/html/rfc6455}{RFC 6455})).
+ * (see \l {RFC 6455})).
  * The \a origin may not contain new line characters, otherwise the connection will be
  * aborted immediately during the handshake phase.
- * \note Currently only V13 (\l {http://tools.ietf.org/html/rfc6455} {RFC 6455}) is supported
+ * \note Currently only V13 (\l {RFC 6455}) is supported
  */
 QWebSocket::QWebSocket(const QString &origin,
                        QWebSocketProtocol::Version version,
@@ -391,7 +397,22 @@ void QWebSocket::close(QWebSocketProtocol::CloseCode closeCode, const QString &r
 void QWebSocket::open(const QUrl &url)
 {
     Q_D(QWebSocket);
-    d->open(url, true);
+    QNetworkRequest request(url);
+    d->open(request, true);
+}
+
+/*!
+    \brief Opens a WebSocket connection using the given \a request.
+    \since 5.6
+
+    The \a request url will be used to open the WebSocket connection.
+    Headers present in the request will be sent to the server in the upgrade request,
+    together with the ones needed for the websocket handshake.
+ */
+void QWebSocket::open(const QNetworkRequest &request)
+{
+    Q_D(QWebSocket);
+    d->open(request, true);
 }
 
 /*!
@@ -514,7 +535,17 @@ QString QWebSocket::resourceName() const
 QUrl QWebSocket::requestUrl() const
 {
     Q_D(const QWebSocket);
-    return d->requestUrl();
+    return d->request().url();
+}
+
+/*!
+    \brief Returns the request that was or will be used to open this socket.
+    \since 5.6
+ */
+QNetworkRequest QWebSocket::request() const
+{
+    Q_D(const QWebSocket);
+    return d->request();
 }
 
 /*!
