@@ -1,31 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Kurt Pattyn <pattyn.kurt@gmail.com>.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 Kurt Pattyn <pattyn.kurt@gmail.com>.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the QtWebSockets module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -269,12 +275,16 @@ void QWebSocketHandshakeRequest::readHandshake(QTextStream &textStream, int maxH
     if (m_requestUrl.isRelative()) {
         // see http://tools.ietf.org/html/rfc6455#page-17
         // No. 4 item in "The requirements for this handshake"
-        m_requestUrl.setAuthority(host);
-        if (!m_requestUrl.userName().isNull()) { // If the username is null, the password must be too.
-            m_isValid = false;
-            clear();
-            return;
+        int idx = host.indexOf(QStringLiteral(":"));
+        bool ok = false;
+        int port = 0;
+        if (idx != -1) {
+            port = host.rightRef(host.length() - idx - 1).toInt(&ok);
+            host.truncate(idx);
         }
+        m_requestUrl.setHost(host);
+        if (ok)
+            m_requestUrl.setPort(port);
     }
     if (m_requestUrl.scheme().isEmpty()) {
         const QString scheme =  isSecure() ? QStringLiteral("wss") : QStringLiteral("ws");
@@ -327,7 +337,7 @@ void QWebSocketHandshakeRequest::readHandshake(QTextStream &textStream, int maxH
 
     //TODO: authentication field
 
-    m_isValid = !(m_requestUrl.host().isEmpty() ||
+    m_isValid = !(host.isEmpty() ||
                   resourceName.isEmpty() ||
                   m_versions.isEmpty() ||
                   m_key.isEmpty() ||
